@@ -1,7 +1,7 @@
 <?php
 
 /*
-* @copyright Copyright (C) 2005-2009 Keyboard Monkeys Ltd. http://www.kb-m.com
+* @copyright Copyright (C) 2005-2010 Keyboard Monkeys Ltd. http://www.kb-m.com
 * @license http://creativecommons.org/licenses/BSD/ BSD License
 * @author Keyboard Monkey Ltd
 * @since  CommunityID 0.9
@@ -20,7 +20,7 @@ class CommunityID_Controller_Action_Helper_ProviderUrl
         $currentUrl = urldecode(Zend_OpenId::selfURL());
 
         if ($config->subdomain->enabled) {
-            $protocol = $this->_actionController->getProtocol();
+            $protocol = Monkeys_Controller_Action::getProtocol();
             preg_match('#(.*)\.'.$config->subdomain->hostname.'#', $currentUrl, $matches);
 
             return "$protocol://"
