@@ -1,11 +1,10 @@
 <?php
 
 /*
-* @copyright Copyright (C) 2005-2009 Keyboard Monkeys Ltd. http://www.kb-m.com
-* @license http://creativecommons.org/licenses/BSD/ BSD License
-* @author Keyboard Monkey Ltd
-* @since  CommunityID 0.9
-* @package CommunityID
+* @copyright Copyright (C) 2005-2010 Keyboard Monkeys Ltd. http://www.kb-m.com
+* @license http://creativecommons.org/licenses/BSD/ BSD Licensese
+* @author Keyboard Monkeys Ltd.
+* @package Monkeys Framework
 * @packager Keyboard Monkeys
 */
 
@@ -17,18 +16,18 @@ class Monkeys_Validate_Username extends Zend_Validate_Abstract
     const BAD = 'bad';
 
     protected $_messageTemplates = array(
-        self::BAD => 'Username can only contain US-ASCII alphanumeric characters, plus any of the symbols $-_.+!*\'(), and "'
+        self::BAD => 'Username can only contain US-ASCII alphanumeric characters, plus any of the symbols $-_.+!*\'(), and "',
     );
 
     public function isValid($value, $context = null)
     {
         $this->_setValue($value);
 
-        if (preg_match('/^[A-Za-z\$-_.\+!\*\'\(\)",]+$/', $value)) {
-            return true;
-        } else {
+        if (!preg_match('/^[A-Za-z\$-_.\+!\*\'\(\)",]+$/', $value)) {
             $this->_error(self::BAD);
             return false;
         }
+
+        return true;
     }
 }
