@@ -16,7 +16,7 @@
  * @package    Zend_Dojo
  * @subpackage View
  * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
- * @version    $Id: Container.php 16541 2009-07-07 06:59:03Z bkarwin $
+ * @version    $Id: Container.php 19058 2009-11-19 19:57:17Z matthew $
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
@@ -26,18 +26,18 @@ require_once 'Zend/Dojo.php';
 /**
  * Container for  Dojo View Helper
  *
- * 
+ *
  * @package    Zend_Dojo
  * @subpackage View
  * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Dojo_View_Helper_Dojo_Container
-{ 
+{
     /**
      * @var Zend_View_Interface
      */
-    public $view; 
+    public $view;
 
     /**
      * addOnLoad capture lock
@@ -67,7 +67,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
      * Dojo version to use from CDN
      * @var string
      */
-    protected $_cdnVersion = '1.2.0';
+    protected $_cdnVersion = '1.3.2';
 
     /**
      * Has the dijit loader been registered?
@@ -159,10 +159,16 @@ class Zend_Dojo_View_Helper_Dojo_Container
      */
     protected $_stylesheets = array();
 
+    /**
+     * Array of onLoad events specific to Zend_Dojo integration operations
+     * @var array
+     */
+    protected $_zendLoadActions = array();
+
     /**
      * Set view object
-     * 
-     * @param  Zend_Dojo_View_Interface $view 
+     *
+     * @param  Zend_Dojo_View_Interface $view
      * @return void
      */
     public function setView(Zend_View_Interface $view)
@@ -172,7 +178,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Enable dojo
-     * 
+     *
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function enable()
@@ -183,7 +189,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Disable dojo
-     * 
+     *
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function disable()
@@ -194,18 +200,18 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Is dojo enabled?
-     * 
+     *
      * @return bool
      */
     public function isEnabled()
     {
         return $this->_enabled;
     }
- 
+
     /**
      * Specify a module to require
-     * 
-     * @param  string $module 
+     *
+     * @param  string $module
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function requireModule($module)
@@ -233,18 +239,18 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Retrieve list of modules to require
-     * 
+     *
      * @return array
      */
     public function getModules()
     {
         return $this->_modules;
     }
- 
+
     /**
      * Register a module path
-     * 
-     * @param  string $path 
+     *
+     * @param  string $path
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function registerModulePath($module, $path)
@@ -259,7 +265,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * List registered module paths
-     * 
+     *
      * @return array
      */
     public function getModulePaths()
@@ -269,8 +275,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Add layer (custom build) path
-     * 
-     * @param  string $path 
+     *
+     * @param  string $path
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function addLayer($path)
@@ -284,7 +290,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Get registered layers
-     * 
+     *
      * @return array
      */
     public function getLayers()
@@ -294,8 +300,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Remove a registered layer
-     * 
-     * @param  string $path 
+     *
+     * @param  string $path
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function removeLayer($path)
@@ -311,7 +317,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Clear all registered layers
-     * 
+     *
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function clearLayers()
@@ -322,8 +328,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Set CDN base path
-     * 
-     * @param  string $url 
+     *
+     * @param  string $url
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setCdnBase($url)
@@ -334,18 +340,18 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Return CDN base URL
-     * 
+     *
      * @return string
      */
     public function getCdnBase()
     {
         return $this->_cdnBase;
     }
- 
+
     /**
      * Use CDN, using version specified
-     * 
-     * @param  string $version 
+     *
+     * @param  string $version
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setCdnVersion($version = null)
@@ -356,10 +362,10 @@ class Zend_Dojo_View_Helper_Dojo_Container
         }
         return $this;
     }
- 
+
     /**
      * Get CDN version
-     * 
+     *
      * @return string
      */
     public function getCdnVersion()
@@ -369,8 +375,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Set CDN path to dojo (relative to CDN base + version)
-     * 
-     * @param  string $path 
+     *
+     * @param  string $path
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setCdnDojoPath($path)
@@ -381,7 +387,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Get CDN path to dojo (relative to CDN base + version)
-     * 
+     *
      * @return string
      */
     public function getCdnDojoPath()
@@ -391,18 +397,18 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Are we using the CDN?
-     * 
+     *
      * @return bool
      */
     public function useCdn()
     {
         return !$this->useLocalPath();
     }
- 
+
     /**
      * Set path to local dojo
-     * 
-     * @param  string $path 
+     *
+     * @param  string $path
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setLocalPath($path)
@@ -414,7 +420,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Get local path to dojo
-     * 
+     *
      * @return string
      */
     public function getLocalPath()
@@ -424,19 +430,19 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Are we using a local path?
-     * 
+     *
      * @return bool
      */
     public function useLocalPath()
     {
         return (null === $this->_localPath) ? false : true;
     }
- 
+
     /**
      * Set Dojo configuration
-     * 
-     * @param  string $option 
-     * @param  mixed $value 
+     *
+     * @param  string $option
+     * @param  mixed $value
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setDjConfig(array $config)
@@ -447,9 +453,9 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Set Dojo configuration option
-     * 
-     * @param  string $option 
-     * @param  mixed $value 
+     *
+     * @param  string $option
+     * @param  mixed $value
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setDjConfigOption($option, $value)
@@ -461,7 +467,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Retrieve dojo configuration values
-     * 
+     *
      * @return array
      */
     public function getDjConfig()
@@ -471,9 +477,9 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Get dojo configuration value
-     * 
-     * @param  string $option 
-     * @param  mixed $default 
+     *
+     * @param  string $option
+     * @param  mixed $default
      * @return mixed
      */
     public function getDjConfigOption($option, $default = null)
@@ -484,11 +490,11 @@ class Zend_Dojo_View_Helper_Dojo_Container
         }
         return $default;
     }
- 
+
     /**
      * Add a stylesheet by module name
-     * 
-     * @param  string $module 
+     *
+     * @param  string $module
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function addStylesheetModule($module)
@@ -506,18 +512,18 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Get all stylesheet modules currently registered
-     * 
+     *
      * @return array
      */
     public function getStylesheetModules()
     {
         return $this->_stylesheetModules;
     }
- 
+
     /**
      * Add a stylesheet
-     * 
-     * @param  string $path 
+     *
+     * @param  string $path
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function addStylesheet($path)
@@ -532,9 +538,9 @@ class Zend_Dojo_View_Helper_Dojo_Container
     /**
      * Register the dojo.css stylesheet?
      *
-     * With no arguments, returns the status of the flag; with arguments, sets 
+     * With no arguments, returns the status of the flag; with arguments, sets
      * the flag and returns the object.
-     * 
+     *
      * @param  null|bool $flag
      * @return Zend_Dojo_View_Helper_Dojo_Container|bool
      */
@@ -550,7 +556,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Retrieve registered stylesheets
-     * 
+     *
      * @return array
      */
     public function getStylesheets()
@@ -564,7 +570,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
      * dojo.addOnLoad accepts:
      * - function name
      * - lambda
-     * 
+     *
      * @param  string $callback Lambda
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
@@ -578,7 +584,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Prepend an onLoad event to the list of onLoad actions
-     * 
+     *
      * @param  string $callback Lambda
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
@@ -592,7 +598,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Retrieve all registered onLoad actions
-     * 
+     *
      * @return array
      */
     public function getOnLoadActions()
@@ -602,7 +608,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Start capturing routines to run onLoad
-     * 
+     *
      * @return bool
      */
     public function onLoadCaptureStart()
@@ -619,7 +625,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Stop capturing routines to run onLoad
-     * 
+     *
      * @return bool
      */
     public function onLoadCaptureEnd()
@@ -633,9 +639,9 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Add a programmatic dijit
-     * 
-     * @param  string $id 
-     * @param  array $params 
+     *
+     * @param  string $id
+     * @param  array $params
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function addDijit($id, array $params)
@@ -655,9 +661,9 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Set a programmatic dijit (overwrites)
-     * 
-     * @param  string $id 
-     * @param  array $params 
+     *
+     * @param  string $id
+     * @param  array $params
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setDijit($id, array $params)
@@ -670,8 +676,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
      * Add multiple dijits at once
      *
      * Expects an array of id => array $params pairs
-     * 
-     * @param  array $dijits 
+     *
+     * @param  array $dijits
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function addDijits(array $dijits)
@@ -686,8 +692,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
      * Set multiple dijits at once (overwrites)
      *
      * Expects an array of id => array $params pairs
-     * 
-     * @param  array $dijits 
+     *
+     * @param  array $dijits
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function setDijits(array $dijits)
@@ -698,8 +704,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Is the given programmatic dijit already registered?
-     * 
-     * @param  string $id 
+     *
+     * @param  string $id
      * @return bool
      */
     public function hasDijit($id)
@@ -709,8 +715,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Retrieve a dijit by id
-     * 
-     * @param  string $id 
+     *
+     * @param  string $id
      * @return array|null
      */
     public function getDijit($id)
@@ -725,7 +731,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
      * Retrieve all dijits
      *
      * Returns dijits as an array of assoc arrays
-     * 
+     *
      * @return array
      */
     public function getDijits()
@@ -735,8 +741,8 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Remove a programmatic dijit if it exists
-     * 
-     * @param  string $id 
+     *
+     * @param  string $id
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function removeDijit($id)
@@ -750,7 +756,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Clear all dijits
-     * 
+     *
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function clearDijits()
@@ -761,7 +767,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Render dijits as JSON structure
-     * 
+     *
      * @return string
      */
     public function dijitsToJson()
@@ -772,7 +778,7 @@ class Zend_Dojo_View_Helper_Dojo_Container
 
     /**
      * Create dijit loader functionality
-     * 
+     *
      * @return void
      */
     public function registerDijitLoader()
@@ -790,7 +796,7 @@ function() {
 }
 EOJ;
             $this->requireModule('dojo.parser');
-            $this->prependOnLoad($js);
+            $this->_addZendLoad($js);
             $this->addJavascript('var zendDijits = ' . $this->dijitsToJson() . ';');
             $this->_dijitLoaderRegistered = true;
         }
@@ -798,8 +804,8 @@ EOJ;
 
     /**
      * Add arbitrary javascript to execute in dojo JS container
-     * 
-     * @param  string $js 
+     *
+     * @param  string $js
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function addJavascript($js)
@@ -819,7 +825,7 @@ EOJ;
 
     /**
      * Return all registered javascript statements
-     * 
+     *
      * @return array
      */
     public function getJavascript()
@@ -829,7 +835,7 @@ EOJ;
 
     /**
      * Clear arbitrary javascript stack
-     * 
+     *
      * @return Zend_Dojo_View_Helper_Dojo_Container
      */
     public function clearJavascript()
@@ -840,7 +846,7 @@ EOJ;
 
     /**
      * Capture arbitrary javascript to include in dojo script
-     * 
+     *
      * @return void
      */
     public function javascriptCaptureStart()
@@ -857,7 +863,7 @@ EOJ;
 
     /**
      * Finish capturing arbitrary javascript to include in dojo script
-     * 
+     *
      * @return true
      */
     public function javascriptCaptureEnd()
@@ -871,7 +877,7 @@ EOJ;
 
     /**
      * String representation of dojo environment
-     * 
+     *
      * @return string
      */
     public function __toString()
@@ -902,7 +908,7 @@ EOJ;
 
     /**
      * Retrieve local path to dojo resources for building relative paths
-     * 
+     *
      * @return string
      */
     protected function _getLocalRelativePath()
@@ -917,7 +923,7 @@ EOJ;
 
     /**
      * Render dojo stylesheets
-     * 
+     *
      * @return string
      */
     protected function _renderStylesheets()
@@ -962,7 +968,7 @@ EOJ;
 
     /**
      * Render DjConfig values
-     * 
+     *
      * @return string
      */
     protected function _renderDjConfig()
@@ -985,10 +991,10 @@ EOJ;
     /**
      * Render dojo script tag
      *
-     * Renders Dojo script tag by utilizing either local path provided or the 
-     * CDN. If any djConfig values were set, they will be serialized and passed 
+     * Renders Dojo script tag by utilizing either local path provided or the
+     * CDN. If any djConfig values were set, they will be serialized and passed
      * with that attribute.
-     * 
+     *
      * @return string
      */
     protected function _renderDojoScriptTag()
@@ -1007,7 +1013,7 @@ EOJ;
 
     /**
      * Render layers (custom builds) as script tags
-     * 
+     *
      * @return string
      */
     protected function _renderLayers()
@@ -1030,7 +1036,7 @@ EOJ;
 
     /**
      * Render dojo module paths and requires
-     * 
+     *
      * @return string
      */
     protected function _renderExtras()
@@ -1051,6 +1057,13 @@ EOJ;
         }
 
         $onLoadActions = array();
+        // Get Zend specific onLoad actions; these will always be first to 
+        // ensure that dijits are created in the correct order
+        foreach ($this->_getZendLoadActions() as $callback) {
+            $onLoadActions[] = 'dojo.addOnLoad(' . $callback . ');';
+        }
+
+        // Get all other onLoad actions
         foreach ($this->getOnLoadActions() as $callback) {
             $onLoadActions[] = 'dojo.addOnLoad(' . $callback . ');';
         }
@@ -1081,4 +1094,33 @@ EOJ;
               . PHP_EOL . '</script>';
         return $html;
     }
+
+    /**
+     * Add an onLoad action related to ZF dijit creation
+     *
+     * This method is public, but prefixed with an underscore to indicate that 
+     * it should not normally be called by userland code. It is pertinent to
+     * ensuring that the correct order of operations occurs during dijit 
+     * creation.
+     * 
+     * @param  string $callback 
+     * @return Zend_Dojo_View_Helper_Dojo_Container
+     */
+    public function _addZendLoad($callback)
+    {
+        if (!in_array($callback, $this->_zendLoadActions, true)) {
+            $this->_zendLoadActions[] = $callback;
+        }
+        return $this;
+    }
+
+    /**
+     * Retrieve all ZF dijit callbacks
+     * 
+     * @return array
+     */
+    public function _getZendLoadActions()
+    {
+        return $this->_zendLoadActions;
+    }
 }
