@@ -1,7 +1,7 @@
 <?php
 
 /*
-* @copyright Copyright (C) 2005-2009 Keyboard Monkeys Ltd. http://www.kb-m.com
+* @copyright Copyright (C) 2005-2010 Keyboard Monkeys Ltd. http://www.kb-m.com
 * @license http://creativecommons.org/licenses/BSD/ BSD License
 * @author Keyboard Monkey Ltd
 * @since  CommunityID 0.9
@@ -17,6 +17,11 @@ class Users_ProfileController extends CommunityID_Controller_Action
             throw new Monkeys_AccessDeniedException();
         }
 
+        $this->view->canEditAccountInfo = !$this->_config->ldap->enabled
+            || ($this->_config->ldap->enabled && $this->_config->ldap->keepRecordsSynced);
+        $this->view->canChangePassword = !$this->_config->ldap->enabled
+            || ($this->_config->ldap->enabled && $this->_config->ldap->canChangePassword);
+
         $this->_helper->actionStack('index', 'login', 'users');
     }
 }
