@@ -7,4 +7,7 @@ $versions = array(
     '1.1.0.RC2',
     '1.1.0',
     '1.1.1',
+    '1.2.0.RC1',
+    '1.2.0.RC2',
+    '1.2.1',
 );
