@@ -799,15 +799,11 @@ COMMID.editAccountInfo = function() {
 COMMID.stats = function() {
     return {
         loadReport: function(report, div, params) {
-            if (params) {
-                params = "?" + params;
-            } else {
-                params = "";
-            }
+            params = params || '';
 
             YAHOO.util.Connect.asyncRequest(
                 "GET",
-                "stats/" + report + params,
+                "stats/reports/index/report/" + report + params,
                 {
                     success: function (responseObj) {
                         COMMID.utils.replaceContent(responseObj, div)
